Struct WpColorRepresentationManagerV1
pub struct WpColorRepresentationManagerV1 { /* private fields */ }wayland and Linux only.Expand description
color representation manager singleton
A singleton global interface used for getting color representation extensions for wl_surface. The extension interfaces allow setting the color representation of surfaces.
Compositors should never remove this global.
See also the Event enum for this interface.
Implementations
impl WpColorRepresentationManagerV1
impl WpColorRepresentationManagerV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the manager
Destroy the wp_color_representation_manager_v1 object. This does not affect any other objects in any way.
pub fn get_surface<U, D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> WpColorRepresentationSurfaceV1
pub fn get_surface<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> WpColorRepresentationSurfaceV1
create a color representation interface for a wl_surface
If a wp_color_representation_surface_v1 object already exists for the given wl_surface, the protocol error surface_exists is raised.
This creates a new color wp_color_representation_surface_v1 object for the given wl_surface.
See the wp_color_representation_surface_v1 interface for more details.